﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using BookApi.Repositories;
using BookApi.Models;

namespace BookApi.Controllers
{
    [Produces("application/json")]
    [Route("api/Books")]
    public class BooksController : Controller
    {
        IBooksRepository bookRepository { get; set; }
        public BooksController(IBooksRepository bookRepository)
        {
            this.bookRepository = bookRepository;
        }

        // GET: api/values
        [HttpGet]
        public IEnumerable<Book> GetAll()
        {
            return bookRepository.FindAll();

        }

        // GET api/values/5
        [HttpGet("{id}")]
        public IActionResult Get(int id)
        {
            var book = bookRepository.Find(id);
            if (book != null)
                return new ObjectResult(book);
            else
                return NotFound();
        }

        // POST api/values
        [HttpPost]
        public IActionResult Create([FromBody]Book bookData)
        {
            if (bookData == null)
            {
                return BadRequest();
            }
            var book = bookRepository.Add(bookData);
            return CreatedAtAction("Get", new { id = book.ID }, book);
        }

        // PUT api/values/5
        [HttpPut("{id}")]
        public IActionResult Update(int id, [FromBody]Book bookData)
        {
            if (bookData == null || bookData.ID != id)
            {
                return BadRequest();
            }

            var book = bookRepository.Find(id);
            if (book == null)
            {
                return NotFound();
            }

            bookRepository.Update(id, bookData);
            return new NoContentResult();
        }

        // DELETE api/values/5
        [HttpDelete("{id}")]
        public IActionResult Delete(int id)
        {
            var book = bookRepository.Find(id);
            if (book == null)
            {
                return NotFound();
            }
            bookRepository.Remove(id);
            return new NoContentResult();
        }

    }
}